==> zio-aws-apigateway_2.13-5.17.151.1-sources.jar: zio/aws/apigateway/model/GetRequestValidatorResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRequestValidatorResponse(
    id: Option[String] = None,
    name: Option[String] = None,
    validateRequestBody: Option[Boolean] = None,
    validateRequestParameters: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse = {
    import GetRequestValidatorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        validateRequestBody.map(value => value: java.lang.Boolean)
      )(_.validateRequestBody)
      .optionallyWith(
        validateRequestParameters.map(value => value: java.lang.Boolean)
      )(_.validateRequestParameters)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.GetRequestValidatorResponse.ReadOnly =
    zio.aws.apigateway.model.GetRequestValidatorResponse.wrap(buildAwsValue())
}
object GetRequestValidatorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.GetRequestValidatorResponse =
      zio.aws.apigateway.model.GetRequestValidatorResponse(
        id.map(value => value),
        name.map(value => value),
        validateRequestBody.map(value => value),
        validateRequestParameters.map(value => value)
      )
    def id: Option[String]
    def name: Option[String]
    def validateRequestBody: Option[Boolean]
    def validateRequestParameters: Option[Boolean]
    def getId: ZIO[Any, AwsError, String] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getValidateRequestBody: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("validateRequestBody", validateRequestBody)
    def getValidateRequestParameters: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("validateRequestParameters", validateRequestParameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
  ) extends zio.aws.apigateway.model.GetRequestValidatorResponse.ReadOnly {
    override val id: Option[String] =
      scala.Option(impl.id()).map(value => value: String)
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val validateRequestBody: Option[Boolean] =
      scala.Option(impl.validateRequestBody()).map(value => value: Boolean)
    override val validateRequestParameters: Option[Boolean] = scala
      .Option(impl.validateRequestParameters())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
  ): zio.aws.apigateway.model.GetRequestValidatorResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_2.13-5.17.193.1-sources.jar: zio/aws/apigateway/model/GetRequestValidatorResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRequestValidatorResponse(
    id: Optional[String] = Optional.Absent,
    name: Optional[String] = Optional.Absent,
    validateRequestBody: Optional[Boolean] = Optional.Absent,
    validateRequestParameters: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse = {
    import GetRequestValidatorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        validateRequestBody.map(value => value: java.lang.Boolean)
      )(_.validateRequestBody)
      .optionallyWith(
        validateRequestParameters.map(value => value: java.lang.Boolean)
      )(_.validateRequestParameters)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.GetRequestValidatorResponse.ReadOnly =
    zio.aws.apigateway.model.GetRequestValidatorResponse.wrap(buildAwsValue())
}
object GetRequestValidatorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.GetRequestValidatorResponse =
      zio.aws.apigateway.model.GetRequestValidatorResponse(
        id.map(value => value),
        name.map(value => value),
        validateRequestBody.map(value => value),
        validateRequestParameters.map(value => value)
      )
    def id: Optional[String]
    def name: Optional[String]
    def validateRequestBody: Optional[Boolean]
    def validateRequestParameters: Optional[Boolean]
    def getId: ZIO[Any, AwsError, String] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getValidateRequestBody: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("validateRequestBody", validateRequestBody)
    def getValidateRequestParameters: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("validateRequestParameters", validateRequestParameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
  ) extends zio.aws.apigateway.model.GetRequestValidatorResponse.ReadOnly {
    override val id: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: String)
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val validateRequestBody: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.validateRequestBody())
      .map(value => value: Boolean)
    override val validateRequestParameters: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.validateRequestParameters())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.GetRequestValidatorResponse
  ): zio.aws.apigateway.model.GetRequestValidatorResponse.ReadOnly =
    new Wrapper(impl)
}
